cli

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Overview

Package cli builds the cobra command tree and drives the TUI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() int

Execute runs the root command and returns a process exit code.

func Version

func Version() string

Version returns the human-readable build version string.

Types

This section is empty.

Jump to